==> keybase-1.0.48.tar.gz: client-1.0.48/shared/chat/conversation/create-team-header/index.js <==
// @flow
import React from 'react'
import {Box, Text} from '../../../common-adapters'
import {globalColors, globalStyles, globalMargins, isMobile} from '../../../styles'

type Props = {
  onShowNewTeamDialog: () => void,
}

const CreateTeamHeader = ({onShowNewTeamDialog}: Props) => (
  <Box style={isMobile ? stylesMobileContainer : stylesDesktopContainer}>
    <Box style={isMobile ? {alignItems: 'center'} : {textAlign: 'center'}}>
      <Text type="BodySemibold" backgroundMode="HighRisk">
        Create a team? You’ll be able to add and remove members as you wish.{' '}
      </Text>
      <Text
        type="BodySemiboldLink"
        style={{color: globalColors.white}}
        onClick={onShowNewTeamDialog}
        underline={true}
        className="underline"
        backgroundMode="Terminal"
      >
        Enter a team name
      </Text>
    </Box>
  </Box>
)

const stylesDesktopContainer = {
  ...globalStyles.flexBoxRow,
  alignItems: 'center',
  backgroundColor: globalColors.blue,
  height: 56,
  justifyContent: 'center',
  minHeight: 56,
  paddingLeft: globalMargins.medium,
  paddingRight: globalMargins.medium,
}

const stylesMobileContainer = {
  ...globalStyles.flexBoxRow,
  alignItems: 'center',
  backgroundColor: globalColors.blue,
  justifyContent: 'center',
  minHeight: 56,
  paddingLeft: globalMargins.medium,
  paddingRight: globalMargins.medium,
  paddingTop: globalMargins.medium,
  paddingBottom: globalMargins.medium,
  marginTop: globalMargins.medium,
  marginBottom: globalMargins.medium,
}

export default CreateTeamHeader

==> keybase-2.1.0.tar.gz: client-2.1.0/shared/chat/conversation/create-team-header/index.js <==
// @flow
import React from 'react'
import {Box, Text} from '../../../common-adapters'
import {globalColors, globalStyles, globalMargins, isMobile} from '../../../styles'

type Props = {
  onShowNewTeamDialog: () => void,
}

const CreateTeamHeader = ({onShowNewTeamDialog}: Props) => (
  <Box style={isMobile ? stylesMobileContainer : stylesDesktopContainer}>
    <Box style={isMobile ? {alignItems: 'center'} : {textAlign: 'center'}}>
      <Text type="BodySemibold" backgroundMode="HighRisk">
        Create a team? You’ll be able to add and remove members as you wish.{' '}
      </Text>
      <Text
        type="BodySemiboldLink"
        style={{color: globalColors.white}}
        onClick={onShowNewTeamDialog}
        underline={true}
        className="underline"
        backgroundMode="Terminal"
      >
        Enter a team name
      </Text>
    </Box>
  </Box>
)

const stylesDesktopContainer = {
  ...globalStyles.flexBoxRow,
  alignItems: 'center',
  backgroundColor: globalColors.blue,
  paddingBottom: globalMargins.tiny,
  paddingTop: globalMargins.tiny,
  justifyContent: 'center',
  paddingLeft: globalMargins.medium,
  paddingRight: globalMargins.medium,
}

const stylesMobileContainer = {
  ...globalStyles.flexBoxRow,
  alignItems: 'center',
  backgroundColor: globalColors.blue,
  justifyContent: 'center',
  paddingLeft: globalMargins.medium,
  paddingRight: globalMargins.medium,
  paddingTop: globalMargins.tiny,
  paddingBottom: globalMargins.tiny,
}

export default CreateTeamHeader
